function R_DEF(directive) {
    return new RegExp(`\\s+\\@${directive}\\([^)]+\\)`, 'gm');
}
// checks if operation has a directive
export function operationHasDirective(operation, directive) {
    return operation.document.includes(`@${directive}`);
}
// removes a directive from string
export function removeDirective(document, directive) {
    if (operationHasDirective({ document }, directive)) {
        return document.replace(R_DEF(directive), '');
    }
    return document;
}
export function removeDirectives(document, directives) {
    return directives.reduce((doc, directive) => removeDirective(doc, directive), document);
}
// tries to find a directive and extract it's arguments
export function extractDirective(operation, directive) {
    const doc = operation.document;
    const directives = doc.match(R_DEF(directive));
    if (directives.length > 1) {
        throw new Error(`The ${directive} directive used multiple times in '${operation.name}' operation`);
    }
    return directives[0];
}
//# sourceMappingURL=directives.js.map