import { initCommonTemplate } from 'graphql-codegen-typescript-common';
import { transformDocumentsFiles } from 'graphql-codegen-core';
import { flattenTypes } from 'graphql-codegen-plugin-helpers';
import * as Handlebars from 'handlebars';
import * as rootTemplate from './root.handlebars';
import { importNgModules } from './helpers/import-ng-modules';
import { gql as gqlHelper } from './helpers/gql';
import gql from 'graphql-tag';
import { generateFragments } from './helpers/generate-fragments';
import { providedIn } from './helpers/provided-in';
import { namedClient } from './helpers/named-client';
import { extname } from 'path';
export const plugin = async (schema, documents, config) => {
    const { templateContext, convert } = initCommonTemplate(Handlebars, schema, config);
    const transformedDocuments = transformDocumentsFiles(schema, documents);
    const flattenDocuments = flattenTypes(transformedDocuments);
    Handlebars.registerHelper('importNgModules', importNgModules);
    Handlebars.registerHelper('gql', gqlHelper(convert));
    Handlebars.registerHelper('providedIn', providedIn);
    Handlebars.registerHelper('namedClient', namedClient);
    Handlebars.registerHelper('generateFragments', generateFragments(convert));
    const hbsContext = Object.assign({}, templateContext, flattenDocuments);
    return Handlebars.compile(rootTemplate)(hbsContext);
};
export const addToSchema = gql `
  directive @NgModule(module: String!) on OBJECT | FIELD
  directive @namedClient(name: String!) on OBJECT | FIELD
`;
export const validate = async (schema, documents, config, outputFile) => {
    if (extname(outputFile) !== '.ts') {
        throw new Error(`Plugin "apollo-angular" requires extension to be ".ts"!`);
    }
};
//# sourceMappingURL=index.js.map